@@ -46,7 +46,7 @@ package TinyDNS::Reader;
 
 use TinyDNS::Record;
 
-our $VERSION = '0.7.6';
+our $VERSION = '0.7.7';
 
 
 
@@ -138,12 +138,16 @@ sub parse
         # Skip empty lines.
         next if ( !$line || !length($line) );
 
-
         #
         #  Ignore "." + ":" records
         #
         next if ( $line =~ /^\s*[:.]/ );
 
+        #
+        #  Ensure the line is lower-cased
+        #
+        $line = lc($line);
+
         #
         #  Construct a new object, and add it to the list.
         #
